
Welcome to cfgy's documentation!
================================

.. toctree::
    :maxdepth: 2
    :caption: Contents:


.. currentmodule:: cfgy.demo


.. autosummary::
    :toctree: _generated
    :template: configclass.rst
    :recursive:

    OverallSettings
    InputTable
